# Genesis 4 Main Input

::: genesis.version4.MainInput

## Main Input Namelists

### Base class

::: genesis.version4.input.core.NameList

### Namelists

::: genesis.version4.Setup
::: genesis.version4.AlterField
::: genesis.version4.AlterSetup
::: genesis.version4.Beam
::: genesis.version4.Efield
::: genesis.version4.Field
::: genesis.version4.ImportBeam
::: genesis.version4.ImportDistribution
::: genesis.version4.ImportField
::: genesis.version4.ImportTransformation
::: genesis.version4.LatticeNamelist
::: genesis.version4.ProfileArray
::: genesis.version4.ProfileConst
::: genesis.version4.ProfileFile
::: genesis.version4.ProfileFileMulti
::: genesis.version4.ProfileGauss
::: genesis.version4.ProfilePolynom
::: genesis.version4.ProfileStep
::: genesis.version4.SequenceConst
::: genesis.version4.SequenceFilelist
::: genesis.version4.SequenceList
::: genesis.version4.SequencePolynom
::: genesis.version4.SequencePower
::: genesis.version4.SequenceRandom
::: genesis.version4.Sponrad
::: genesis.version4.Time
::: genesis.version4.Track
::: genesis.version4.Wake
::: genesis.version4.Write
